%load Prob_Dist_all_1000_new
close all

% Assuming you have already calculated 'P_ground_truth' and 'P_collective' from the saved data

% Calculate the Bhattacharyya distance for each cost
%num_costs_collective = size(P_collective_pdf, 2);
num_stimulus_values = size(P_collective_pdf, 3);

%Bhattacharyya_distances = zeros(num_costs_collective, 1);
%Bhattacharyya_distances_CI = zeros(num_costs_collective, 2);

for cost_idx = 20 %1: num_costs_collective
    % Extract the probability distributions for the ground truth and the collective observer
    P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, num_stimulus_values);
    P_collective_dist = reshape(P_collective_pdf(:, cost_idx, :), [], num_stimulus_values);

    % Calculate the Bhattacharyya coefficient
    Bhattacharyya_coefficient = sum(sqrt(P_ground_truth_dist .* P_collective_dist), 2);

    % Calculate the Bhattacharyya distance
    Bhattacharyya_distances_coll=  (-log(Bhattacharyya_coefficient));

    % Calculate the 95% confidence interval for the Bhattacharyya distance
    %Bhattacharyya_distances_CI(cost_idx, :) = prctile(-log(Bhattacharyya_coefficient), [2.5, 97.5]);
end

 

%Bhattacharyya_distances_avg = zeros(num_costs_collective, 1);
%Bhattacharyya_distances_CI_avg = zeros(num_costs_collective, 2);

% Calculate the Bhattacharyya distance for each cost
for cost_idx = 20 %1: num_costs_collective
    % Extract the probability distributions for the ground truth and the average observer
    P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, num_stimulus_values);
    P_average_dist = reshape(P_average_pdf(:, cost_idx, :), [], num_stimulus_values);

    % Calculate the Bhattacharyya coefficient
    Bhattacharyya_coefficient_avg = sum(sqrt(P_ground_truth_dist .* P_average_dist), 2);

    % Calculate the Bhattacharyya distance
    Bhattacharyya_distances_avg = (-log(Bhattacharyya_coefficient_avg));

    % Calculate the 95% confidence interval for the Bhattacharyya distance
   % Bhattacharyya_distances_CI_avg(cost_idx, :) = prctile(-log(Bhattacharyya_coefficient_avg), [2.5, 97.5]);
end


% Bhattacharyya_distances_rbs = zeros(num_costs_collective, 1);
% Bhattacharyya_distances_CI_rbs = zeros(num_costs_collective, 2);

% Calculate the Bhattacharyya distance for each cost
for cost_idx = 20 %1: num_costs_collective
    % Extract the probability distributions for the ground truth and the RBS method
    P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, num_stimulus_values);
    P_rbs_dist = reshape(P_rbs_pdf(:, cost_idx, :), [], num_stimulus_values);

    % Calculate the Bhattacharyya coefficient
    Bhattacharyya_coefficient_rbs = sum(sqrt(P_ground_truth_dist .* P_rbs_dist), 2);

    % Calculate the Bhattacharyya distance
    Bhattacharyya_distances_rbs = (-log(Bhattacharyya_coefficient_rbs));

    % Calculate the 95% confidence interval for the Bhattacharyya distance
   % Bhattacharyya_distances_CI_rbs(cost_idx, :) = prctile(-log(Bhattacharyya_coefficient_rbs), [2.5, 97.5]);
end

figure;

% Bin edges and bin width
binEdges = 0:0.002:0.1;
binWidth = binEdges(2) - binEdges(1); % Calculate the bin width

% Plot the Collective Error histogram
h1 = histogram('BinEdges', binEdges, 'FaceColor', 'r', 'EdgeColor', 'k', 'LineStyle', '-', 'FaceAlpha', 0.5);
h1.BinCounts = histcounts(Bhattacharyya_distances_coll, binEdges, 'Normalization', 'probability');
hold on;

% Fit and plot the scaled fitted distribution for Collective Error
pd_collective = fitdist(Bhattacharyya_distances_coll, 'Kernel', 'BandWidth', 0.005);
x = linspace(0, 0.1, numel(binEdges) * 10);
y = pdf(pd_collective, x) * binWidth; % Remove scaling by count
plot(x, y, 'k-', 'LineWidth', 2);

% Plot the Average Error histogram
h2 = histogram('BinEdges', binEdges, 'FaceColor', 'g', 'EdgeColor', 'k', 'LineStyle', '-', 'FaceAlpha', 0.5);
h2.BinCounts = histcounts(Bhattacharyya_distances_avg, binEdges, 'Normalization', 'probability');

% Fit and plot the scaled fitted distribution for Average Error
pd_average = fitdist(Bhattacharyya_distances_avg, 'Kernel', 'BandWidth', 0.005);
y = pdf(pd_average, x) * binWidth; % Remove scaling by count
plot(x, y, 'k-', 'LineWidth', 2);

% Plot the RBS Error histogram
h3 = histogram('BinEdges', binEdges, 'FaceColor', 'b', 'EdgeColor', 'k', 'LineStyle', '-', 'FaceAlpha', 0.5);
h3.BinCounts = histcounts(Bhattacharyya_distances_rbs, binEdges, 'Normalization', 'probability');

% Fit and plot the scaled fitted distribution for RBS Error
pd_rbs = fitdist(Bhattacharyya_distances_rbs, 'Kernel', 'BandWidth', 0.005);
y = pdf(pd_rbs, x) * binWidth; % Remove scaling by count
plot(x, y, 'k-', 'LineWidth', 2);

xlabel('Bhattacharyya distanc');
ylabel('Density'); % Change y-axis label
set(gca, 'fontsize', 14); % Set font size for axes
xlim([0, 0.06]);

% Add a legend with the appropriate entries
legend([h1, h2, h3], 'Collective Observer', 'Average Observer', 'Common approach', 'Location', 'northeast');
grid on;
matlab2tikz('./plots_statistics_BD/hist_BD.tex', 'standalone', true);
saveas(gcf, './plots_statistics_BD/hist_BD.pdf');



