% Define the parameters
sigma_sq = 25;
sigma_0_sq = 25;
mu_bar = 30;
warning('off')
close all

% Define the range for x and mu
x_range = 0:0.01:51;  % Adjust the range as needed for your problem
mu_range = 0:0.01:10; % Adjust the range as needed for your problem

% Initialize the SUR vector
SUR = zeros(size(x_range));

% Calculate the SUR
for i = 1:length(x_range)
    x = x_range(i);
    integrand = @(mu) normcdf(x, mu, sqrt(sigma_sq)) .* normpdf(mu, mu_bar, sqrt(sigma_0_sq));
    SUR(i) = 1 - integral(integrand, -Inf, Inf);
end

% Plot the SUR
figure;
plot(x_range, SUR, 'LineWidth', 2,'Color','red');
xlabel('$\mathrm{x}$', 'Interpreter', 'latex');
%ylabel('SUR');
%title('SUR');
grid on;

hold on

% Using the traditional approach
hat_SUR = 1 - normcdf(x_range, mu_bar, sqrt(sigma_0_sq));

% Plot the SUR
plot(x_range, hat_SUR, 'LineWidth', 2,'Color','blue');

% Plot the SUR values at x=12 with dotted lines to the axes
x_value = 22;
SUR_at_x_value = interp1(x_range, SUR, x_value, 'linear');
hat_SUR_at_x_value = interp1(x_range, hat_SUR, x_value, 'linear');

plot([x_value, x_value], [0, SUR_at_x_value], 'r--', 'LineWidth', 1);
plot([0, x_value], [SUR_at_x_value, SUR_at_x_value], 'r--', 'LineWidth', 1);

plot([x_value, x_value], [0, hat_SUR_at_x_value], 'b--', 'LineWidth', 1);
plot([0, x_value], [hat_SUR_at_x_value, hat_SUR_at_x_value], 'b--', 'LineWidth', 1);


% Add "x=22" label vertically to the dotted line connecting SUR curve and x-axis
text(x_value-1, .3, '$\mathrm{x = 22}$', 'HorizontalAlignment', 'center', 'Rotation', 90,'Interpreter', 'latex');

% Add the value of SUR at x=22 next to the dotted line connecting the curve and y-axis
text(15, SUR_at_x_value - 0.025, ['SUR = ', num2str(SUR_at_x_value, '%.3f')],'HorizontalAlignment', 'right','color','red','Interpreter', 'latex');
%text(15, SUR_at_x_value - 0.025, [num2str(SUR_at_x_value, '%.3f')],'HorizontalAlignment', 'right','color','red','Interpreter', 'latex','FontSize',12);

text(15, hat_SUR_at_x_value + 0.02, ['$\widehat{\mathrm{SUR}} = ', num2str(hat_SUR_at_x_value, '%.3f'), '$'], 'HorizontalAlignment', 'right', 'Color', 'blue', 'Interpreter', 'latex');
%text(15, hat_SUR_at_x_value + 0.02, [ num2str(hat_SUR_at_x_value, '%.3f')], 'HorizontalAlignment', 'right', 'Color', 'blue', 'Interpreter', 'latex','FontSize',12);


% Legend for the plot
 
 legend( 'SUR','$$\widehat{\mathrm{SUR}}$$','Interpreter','Latex','FontSize', 12, 'Location', 'southwest');
set(gcf,'color','w');
set(gca,'FontSize',14)

fprintf('SUR value at x = %.2f is %.4f\n', x_value, SUR_at_x_value);
fprintf('$\widehat{SUR}$ value at x = %.2f is %.4f\n', x_value, hat_SUR_at_x_value);

set(gca,'fontsize',14);
set(gca,'fontname','times')
hold off
 set(gca, 'Color', 'white');
matlab2tikz('./plots_statistics_BD/SUR_hat_SUR2.tex', 'standalone', true);
saveas(gcf, './plots_statistics_BD/SUR_hat_SUR2.pdf');
saveas(gcf, './plots_statistics_BD/SUR_hat_SUR2.eps','epsc')
