
clear
clc
% Load the simulated data. Run estimate_prob_distributions_600_no_lapses.m
% to regenerate this mat file
load('Prob_Dist_all_1000_runs.mat')

close all

 %% Plot Figure 3.a (Collective observer)

% Assuming you have already calculated 'P_ground_truth' and 'P_collective' from the saved data

% Calculate the Bhattacharyya distance for each cost
num_costs_collective = size(P_collective_pdf, 2);
num_stimulus_values = size(P_collective_pdf, 3);

Bhattacharyya_distances = zeros(num_costs_collective, 1);
Bhattacharyya_distances_CI = zeros(num_costs_collective, 2);

for cost_idx = 1:num_costs_collective
    % Extract the probability distributions for the ground truth and the collective observer
    P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, num_stimulus_values);
    P_collective_dist = reshape(P_collective_pdf(:, cost_idx, :), [], num_stimulus_values);

    % Calculate the Bhattacharyya coefficient
    Bhattacharyya_coefficient = sum(sqrt(P_ground_truth_dist .* P_collective_dist), 2);

    % Calculate the Bhattacharyya distance
    Bhattacharyya_distances(cost_idx) = mean(-log(Bhattacharyya_coefficient));

    % Calculate the 95% confidence interval for the Bhattacharyya distance
    Bhattacharyya_distances_CI(cost_idx, :) = prctile(-log(Bhattacharyya_coefficient), [2.5, 97.5]);
end


% Plot the Bhattacharyya distance versus the cost with 95% confidence interval
cost_values = 30:30:600; % Adjust the cost_values to start from 30 and increment by 30
figure;

% Plot the mean Bhattacharyya distances as a red continuous line
plot(cost_values, Bhattacharyya_distances', 'r', 'LineWidth', 2);

hold on;

% Plot the 95% confidence intervals as a gray shaded area
fill([cost_values, fliplr(cost_values)], ...
    [Bhattacharyya_distances_CI(:, 1)', fliplr(Bhattacharyya_distances_CI(:, 2)')], 'k', 'FaceAlpha', 0.2);

hold off;

xlabel('PCs');
ylabel('Bhattacharyya distance');
%title('Bhattacharyya Distance vs Cost with 95% CI');
grid on; set(gca,'fontsize',14);
ylim([0 0.3])

% Customize the x-axis labels
%xticks(cost_values);
%xticklabels(arrayfun(@num2str, cost_values, 'UniformOutput', false));
matlab2tikz('./Figs_3_and_4/Bhattacharyya_distance_collective_observer.tex','standalone',true);
saveas(gcf,'./Figs_3_and_4/Bhattacharyya_distance_collective_observer.pdf');
close all

 %% Plot Figure 3.b (Average observer)
% Assuming you have already calculated 'P_average' and 'P_ground_truth' from the saved data

% Calculate the Bhattacharyya distance for each cost
num_costs_average = size(P_average_pdf, 2);
num_stimulus_values = size(P_average_pdf, 3);

Bhattacharyya_distances_average = zeros(num_costs_average, 1);
Bhattacharyya_distances_CI_average = zeros(num_costs_average, 2);

for cost_idx = 1:num_costs_average
    % Extract the probability distributions for the ground truth and the average observer
    P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, num_stimulus_values);
    P_average_dist = reshape(P_average_pdf(:, cost_idx, :), [], num_stimulus_values);

    % Calculate the Bhattacharyya coefficient
    Bhattacharyya_coefficient_sum = sum(sqrt(P_ground_truth_dist .* P_average_dist), 2);

    % Calculate the Bhattacharyya distance
    Bhattacharyya_distances_average(cost_idx) = mean(-log(Bhattacharyya_coefficient_sum));

    % Calculate the 95% confidence interval for the Bhattacharyya distance
    Bhattacharyya_distances_CI_average(cost_idx, :) = prctile(-log(Bhattacharyya_coefficient_sum), [2.5, 97.5]);
end

% Plot the Bhattacharyya distance versus the cost with 95% confidence interval for the average observer
cost_values_average = 1:num_costs_average;



% --- Calculate the Bhattacharyya distance for P_average ---

% Initialize arrays to store Bhattacharyya distances and confidence intervals for P_average
Bhattacharyya_distances_avg = zeros(num_costs_collective, 1);
Bhattacharyya_distances_CI_avg = zeros(num_costs_collective, 2);

% Calculate the Bhattacharyya distance for each cost
for cost_idx = 1:num_costs_collective
    % Extract the probability distributions for the ground truth and the average observer
    P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, num_stimulus_values);
    P_average_dist = reshape(P_average_pdf(:, cost_idx, :), [], num_stimulus_values);

    % Calculate the Bhattacharyya coefficient
    Bhattacharyya_coefficient_avg = sum(sqrt(P_ground_truth_dist .* P_average_dist), 2);

    % Calculate the Bhattacharyya distance
    Bhattacharyya_distances_avg(cost_idx) = mean(-log(Bhattacharyya_coefficient_avg));

    % Calculate the 95% confidence interval for the Bhattacharyya distance
    Bhattacharyya_distances_CI_avg(cost_idx, :) = prctile(-log(Bhattacharyya_coefficient_avg), [2.5, 97.5]);
end


% Plot the Bhattacharyya distance for P_average as a blue continuous line
figure;
plot(cost_values, mean(Bhattacharyya_distances_avg, 2), 'r', 'LineWidth', 2);
hold on;

% Plot the 95% confidence intervals for P_average as a gray shaded area
fill([cost_values, fliplr(cost_values)], ...
    [Bhattacharyya_distances_CI_avg(:, 1)', fliplr(Bhattacharyya_distances_CI_avg(:, 2)')], 'k', 'FaceAlpha', 0.2);

hold off;

xlabel('PCs');
ylabel('Bhattacharyya distance');
%title('Bhattacharyya Distance for P\_average with 95% CI');
grid on; set(gca,'fontsize',14);
ylim([0 0.3])
matlab2tikz('./Figs_3_and_4/Bhattacharyya_distance_average_observer.tex','standalone',true);
saveas(gcf,'./Figs_3_and_4/Bhattacharyya_distance_average_observer.pdf');
close all

%----------------
%% Plot Figure 3.c (Common approach)
%Relaxed forced choice (RBS) method
% --- Calculate the Bhattacharyya distance for P_rbs ---

% Initialize arrays to store Bhattacharyya distances and confidence intervals for P_rbs
Bhattacharyya_distances_rbs = zeros(num_costs_collective, 1);
Bhattacharyya_distances_CI_rbs = zeros(num_costs_collective, 2);

% Calculate the Bhattacharyya distance for each cost
for cost_idx = 1:num_costs_collective
    % Extract the probability distributions for the ground truth and the RBS method
    P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, num_stimulus_values);
    P_rbs_dist = reshape(P_rbs_pdf(:, cost_idx, :), [], num_stimulus_values);

    % Calculate the Bhattacharyya coefficient
    Bhattacharyya_coefficient_rbs = sum(sqrt(P_ground_truth_dist .* P_rbs_dist), 2);

    % Calculate the Bhattacharyya distance
    Bhattacharyya_distances_rbs(cost_idx) = mean(-log(Bhattacharyya_coefficient_rbs));

    % Calculate the 95% confidence interval for the Bhattacharyya distance
    Bhattacharyya_distances_CI_rbs(cost_idx, :) = prctile(-log(Bhattacharyya_coefficient_rbs), [2.5, 97.5]);
end

% --- Plot all Bhattacharyya distances in the same graph ---

% Assuming you have already calculated 'Bhattacharyya_distances_rbs' and 'Bhattacharyya_distances_CI_rbs', and also have 'P_rbs' available.

figure;
plot(cost_values, mean(Bhattacharyya_distances_rbs, 2), 'r', 'LineWidth', 2);
hold on;

% Plot the 95% confidence intervals for P_rbs as a gray shaded area
fill([cost_values, fliplr(cost_values)], ...
    [Bhattacharyya_distances_CI_rbs(:, 1)', fliplr(Bhattacharyya_distances_CI_rbs(:, 2)')], 'k', 'FaceAlpha', 0.2);

hold off;

xlabel('PCs');
ylabel('Bhattacharyya distance');
%title('Bhattacharyya Distance for P\_rbs with 95% CI');
grid on; set(gca,'fontsize',14);
ylim([0 0.3])
matlab2tikz('./Figs_3_and_4/Bhattacharyya_distance_RBS.tex','standalone',true);
saveas(gcf,'./Figs_3_and_4/Bhattacharyya_distance_RBS.pdf');
close all



 %% Plot Figure 4.a (Average Bhattacharyya distance vs. PCs)
%Number of paired comparisons needed to meet the accuracy constraint.

 % Compute the negative logarithmic Bhattacharyya distance for each method
NL_Bhattacharyya_distances = ([mean(Bhattacharyya_distances, 2), ...
    mean(Bhattacharyya_distances_avg, 2), ...
    mean(Bhattacharyya_distances_rbs, 2)]);

% Set up colors and line styles for the plot
line_colors = lines(4);
line_styles = {'--', ':', '-.', '-'};

 

figure;
plot(NL_Bhattacharyya_distances(:,1), cost_values, ...
    'Color', 'r', 'LineStyle', line_styles{1}, 'LineWidth', 2);
hold on;

plot(NL_Bhattacharyya_distances(:,2), cost_values, ...
    'Color', 'g', 'LineStyle', line_styles{2}, 'LineWidth', 2);
plot(NL_Bhattacharyya_distances(:,3), cost_values, ...
    'Color', 'b', 'LineStyle', line_styles{3}, 'LineWidth', 2);


hold off;

% Set the x-axis to be logarithmic
set(gca, 'XScale', 'log');

xlabel('Bhattacharyya distance');
ylabel('PCs');
%title('Bhattacharyya Distance for Different Methods');
legend('Collective observe', 'Average observer', 'Common SUR estimation', 'Location', 'best');
grid on; set(gca,'fontsize',14);
set(gca,'fontsize',14);

matlab2tikz('./Figs_3_and_4/Log_Bhattacharyya_distance.tex','standalone',true);
saveas(gcf,'./Figs_3_and_4/Log_Bhattacharyya_distance.pdf');


%----------------------------------
close all

%%

 
%  Finding the SUR at one of the runs that its Bhattacharyya distance has
%  the meanimum distance from the mean Bhattacharyya distance at cost 600
%  PCs for different methods

%Collective observer
cost_idx = 20;
num_stimulus_values = size(P_average_pdf, 3);

P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, num_stimulus_values);
P_collective_dist = reshape(P_collective_pdf(:, cost_idx, :), [], num_stimulus_values);

% Calculate the Bhattacharyya coefficient
Bhattacharyya_coefficient_collective = sum(sqrt(P_ground_truth_dist .* P_collective_dist), 2);

% Calculate the Bhattacharyya distance
%Bhattacharyya_distances_avg = mean(-log(Bhattacharyya_coefficient_collective));
%Bhattacharyya_distances_for_cost = -log(Bhattacharyya_coefficient_collective);




% Calculate the absolute differences between Bhattacharyya_distances_for_cost and Bhattacharyya_distances_avg
%differences = abs(Bhattacharyya_distances_for_cost - Bhattacharyya_distances_avg);

% Find the index of the minimum difference


%Average observer

%cost_idx = 20;
%P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, num_stimulus_values);
P_average_dist = reshape(P_average_pdf(:, cost_idx, :), [], num_stimulus_values);

% Calculate the Bhattacharyya coefficient
Bhattacharyya_coefficient_avg = sum(sqrt(P_ground_truth_dist .* P_average_dist), 2);

% Calculate the Bhattacharyya distance
%Bhattacharyya_distances_avg = mean(-log(Bhattacharyya_coefficient_avg));
%Bhattacharyya_distances_for_cost = -log(Bhattacharyya_coefficient_avg);



% Calculate the absolute differences between Bhattacharyya_distances_for_cost and Bhattacharyya_distances_avg
%differences = abs(Bhattacharyya_distances_for_cost - Bhattacharyya_distances_avg);

% Find the index of the minimum difference

 
%Common approuch

% Calculate the Bhattacharyya coefficient
Bhattacharyya_coefficient_rbs = sum(sqrt(P_ground_truth_dist .* P_rbs_dist), 2);

% Calculate the Bhattacharyya distance
Bhattacharyya_distances_avg = mean(-log(Bhattacharyya_coefficient_rbs));
Bhattacharyya_distances_for_cost = -log(Bhattacharyya_coefficient_rbs);


% Calculate the absolute differences between Bhattacharyya_distances_for_cost and Bhattacharyya_distances_avg
differences = abs(Bhattacharyya_distances_for_cost - Bhattacharyya_distances_avg);

% SUR Analysis: Bhattacharyya Distance and Error Plots

% Parameters
costIndex = 20;
numStimulusValues = size(P_average_pdf, 3);

% Calculate Bhattacharyya Distances and Errors

% Collective Observer
P_ground_truth_dist = reshape(P_ground_truth_pdf, 1, numStimulusValues);
P_collective_dist = reshape(P_collective_pdf(:, costIndex, :), [], numStimulusValues);

Bhattacharyya_coeff_collective = sum(sqrt(P_ground_truth_dist .* P_collective_dist), 2);
Bhattacharyya_dist_avg_collective = mean(-log(Bhattacharyya_coeff_collective));

Bhattacharyya_dist_for_cost_collective = -log(Bhattacharyya_coeff_collective);

differences_collective = abs(Bhattacharyya_dist_for_cost_collective - Bhattacharyya_dist_avg_collective);
[minDifference_coll, index_coll] = min(differences_collective);
Difference_coll = Bhattacharyya_dist_for_cost_collective(index_coll);

% Average Observer
P_average_dist = reshape(P_average_pdf(:, costIndex, :), [], numStimulusValues);

Bhattacharyya_coeff_avg = sum(sqrt(P_ground_truth_dist .* P_average_dist), 2);
Bhattacharyya_dist_avg_avg = mean(-log(Bhattacharyya_coeff_avg));

Bhattacharyya_dist_for_cost_avg = -log(Bhattacharyya_coeff_avg);

differences_avg = abs(Bhattacharyya_dist_for_cost_avg - Bhattacharyya_dist_avg_avg);
[minDifference_avg, index_avg] = min(differences_avg);
Difference_avg = Bhattacharyya_dist_for_cost_avg(index_avg);

% Common Approach
P_rbs_dist = reshape(P_rbs_pdf(:, costIndex, :), [], numStimulusValues);

Bhattacharyya_coeff_rbs = sum(sqrt(P_ground_truth_dist .* P_rbs_dist), 2);
Bhattacharyya_dist_avg_rbs = mean(-log(Bhattacharyya_coeff_rbs));

Bhattacharyya_dist_for_cost_rbs = -log(Bhattacharyya_coeff_rbs);

differences_rbs = abs(Bhattacharyya_dist_for_cost_rbs - Bhattacharyya_dist_avg_rbs);
[minDifference_rbs, index_rbs] = min(differences_rbs);
Difference_rbs = Bhattacharyya_dist_for_cost_rbs(index_rbs);

% % CCDF (SUR) Calculation

% Plot CCDFs and Errors


ccdf_collective = 1- P_collective_cdf(:, end, :);
ccdf_average = 1-P_average_cdf(:, end, :);
ccdf_rbs = 1-P_rbs_cdf(:, end, :);
 %
% Calculate the mean CCDF for each method and the ground truth
mean_ccdf_collective = mean(ccdf_collective, 1);
mean_ccdf_collective = squeeze(mean_ccdf_collective); % Remove singleton dimension

mean_ccdf_average = mean(ccdf_average, 1);
mean_ccdf_average = squeeze(mean_ccdf_average); % Remove singleton dimension

mean_ccdf_rbs = mean(ccdf_rbs, 1);
mean_ccdf_rbs = squeeze(mean_ccdf_rbs); % Remove singleton dimension
 

% Calculate the CCDF from the ground truth PDF
ccdf_ground_truth = 1-P_ground_truth_cdf;


% signed errir
% Calculate the signed error for each method
ccdf_collective = squeeze(ccdf_collective);
% Calculate the absolute error for each data point
abs_error_coll = abs(ccdf_collective - repmat(ccdf_ground_truth', size(ccdf_collective, 1), 1));

%Calculate the mean absolute error
error_collective2 = mean(abs_error_coll, 2);

ccdf_average = squeeze(ccdf_average);
% Calculate the absolute error for each data point
abs_error_avg = abs(ccdf_average - repmat(ccdf_ground_truth', size(ccdf_average, 1), 1));
error_average2 = mean(abs_error_avg, 2);

ccdf_rbs = squeeze(ccdf_rbs);

abs_error_rbs = abs(ccdf_rbs - repmat(ccdf_ground_truth', size(ccdf_rbs, 1), 1));


error_rbs2 =  mean(abs_error_rbs, 2);
close all


 
%% Plot Figure 4.b 
%Histograms of the MAEs of SUR estimates from 600 PCs over 51 distortion levels.
figure;
% Bin edges and bin width
binEdges = 0:0.002:0.1;
binWidth = binEdges(2) - binEdges(1); % Calculate the bin width

% Plot the Collective Error histogram
h1 = histogram('BinEdges', binEdges, 'FaceColor', 'r', 'EdgeColor', 'k', 'LineStyle', '-', 'FaceAlpha', 0.5);
h1.BinCounts = histcounts(error_collective2, binEdges, 'Normalization', 'probability');
hold on;

% Fit and plot the scaled fitted distribution for Collective Error
pd_collective = fitdist(error_collective2, 'Kernel', 'BandWidth', 0.005);
x = linspace(0, 0.1, numel(binEdges) * 10);
y = pdf(pd_collective, x) * binWidth; % Remove scaling by count
plot(x, y, 'k-', 'LineWidth', 2);

% Plot the Average Error histogram
h2 = histogram('BinEdges', binEdges, 'FaceColor', 'g', 'EdgeColor', 'k', 'LineStyle', '-', 'FaceAlpha', 0.5);
h2.BinCounts = histcounts(error_average2, binEdges, 'Normalization', 'probability');

% Fit and plot the scaled fitted distribution for Average Error
pd_average = fitdist(error_average2, 'Kernel', 'BandWidth', 0.005);
y = pdf(pd_average, x) * binWidth; % Remove scaling by count
plot(x, y, 'k-', 'LineWidth', 2);

% Plot the RBS Error histogram
h3 = histogram('BinEdges', binEdges, 'FaceColor', 'b', 'EdgeColor', 'k', 'LineStyle', '-', 'FaceAlpha', 0.5);
h3.BinCounts = histcounts(error_rbs2, binEdges, 'Normalization', 'probability');

% Fit and plot the scaled fitted distribution for RBS Error
pd_rbs = fitdist(error_rbs2, 'Kernel', 'BandWidth', 0.005);
y = pdf(pd_rbs, x) * binWidth; % Remove scaling by count
plot(x, y, 'k-', 'LineWidth', 2);

xlabel('Error');
ylabel('Density'); % Change y-axis label
set(gca, 'fontsize', 14); % Set font size for axes
xlim([0, 0.08]);

% Add a legend with the appropriate entries
legend([h1, h2, h3], 'Collective Observer', 'Average Observer', 'Common approach', 'Location', 'northeast');
grid on;
matlab2tikz('./Figs_3_and_4/hist_error6.tex', 'standalone', true);
saveas(gcf, './Figs_3_and_4/hist_error6.pdf');

close all
% signed errir

 
%% Plot Figure 4_c 
%Signed SUR error, averaged over all simulation runs with 600 PCs.
% Calculate the signed error for each method
error_collective =  mean_ccdf_collective-ccdf_ground_truth;
error_average =   mean_ccdf_average - ccdf_ground_truth;
error_rbs =   mean_ccdf_rbs- ccdf_ground_truth;

% Plot the signed error for all methods
figure;
plot(stimulus_values,error_collective, 'r--', 'LineWidth', 2);
hold on;
plot(stimulus_values,  error_average, 'g:', 'LineWidth', 2);
%plot(stimulus_values, [error_rbs(1); error_rbs], 'b-.', 'LineWidth', 2);
plot(stimulus_values, error_rbs, 'b-.', 'LineWidth', 2);

xlabel('Distortion Levels');
ylabel('Error');
% title('Signed Error (SUR of Each Method -  Ground Truth SUR )');
legend('Collective observer', 'Average observer', 'Common SUR estimation', 'Location', 'northeast');
grid on; set(gca,'fontsize',14);
hold off;
xlim([0,51])
matlab2tikz('./Figs_3_and_4/SUR_error.tex','standalone',true);
saveas(gcf,'./Figs_3_and_4/SUR_error.pdf');
close all

 


