clear;
clc;

% Load necessary packages and data
addpath(genpath("./plot_ci"));
addpath(genpath("./mQUESTPlus"));
addpath(genpath("./matlab2tikz_code"));

% Load data for the collective observer
%load('result_collective_observer_300_200_clean.mat')
load('result_collective_observer_600_1000_parallel.mat')

% Number of simulated observers (population size)
num_simulated_observers = length(thresholds);

% Create stimulus values as a column vector
stimulus_values = (0:0.01:51)';

% Initialize matrix to store outcome proportions for all observers
outcome_proportions_gt_pdf_all = zeros(length(stimulus_values), 1);
outcome_proportions_gt_cdf_all = zeros(length(stimulus_values), 1);
% Calculate outcome proportions for each observer
for observer_index = 1:num_simulated_observers
    % Get stimulus for this trial
    observer_params = [thresholds(observer_index), slopes(observer_index), 0];
    outcome_proportions1 = normpdf(stimulus_values, observer_params(1),observer_params(2));
    outcome_proportions2 = normcdf(stimulus_values, observer_params(1),observer_params(2));

    outcome_proportions_gt_pdf_all = outcome_proportions_gt_pdf_all + outcome_proportions1/sum(outcome_proportions1);
    outcome_proportions_gt_cdf_all = outcome_proportions_gt_cdf_all + outcome_proportions2;%
end

% Calculate the ground truth probability distribution over stimuli
%P_ground_truth_pdf = outcome_proportions_gt_all / num_simulated_observers;

% Compute the cumulative distribution function (CDF) and probability density function (PDF) from ground truth data
%CDF_ground_truth = P_ground_truth_pdf(:, 2);
%PDF_ground_truth = diff(CDF_ground_truth) ./ diff(stimulus_values);
P_ground_truth_pdf = outcome_proportions_gt_pdf_all / num_simulated_observers; % Ground truth pdf
P_ground_truth_cdf = outcome_proportions_gt_cdf_all / num_simulated_observers; % Ground truth cdf

% --- Calculating the estimated JND collective distribution for the "collective observer" ---

%load('result_collective_observer_300_200_clean.mat')

num_iterations_collective = size(thresholdsMLEQuest_all, 1); % Number of iterations
num_costs_collective = size(thresholdsMLEQuest_all, 2); % Number of different costs the approach is evaluated at.
P_collective_pdf = nan(num_iterations_collective, num_costs_collective, length(stimulus_values) );
P_collective_cdf = nan(num_iterations_collective, num_costs_collective, length(stimulus_values) );

for itr = 1:num_iterations_collective
    for cost_idx = 1:num_costs_collective
        %  outcome_proportions_collective = zeros(length(stimulus_values), 2);
        outcome_proportions_collective_pdf = zeros(length(stimulus_values), 1);
        outcome_proportions_collective_cdf = zeros(length(stimulus_values), 1);
        collective_params = [thresholdsMLEQuest_all{itr, cost_idx}, slopesMLEQuest_all{itr, cost_idx}, 0];
        %outcome_proportions = qpPFNormal(stimulus_values, collective_params);
        outcome_proportions1 = normpdf(stimulus_values, collective_params(1),collective_params(2));
        outcome_proportions2 = normcdf(stimulus_values, collective_params(1),collective_params(2));

        outcome_proportions_collective_pdf = outcome_proportions_collective_pdf + outcome_proportions1/sum(outcome_proportions1);
        outcome_proportions_collective_cdf = outcome_proportions_collective_cdf + outcome_proportions2;%

        % outcome_proportions_collective = outcome_proportions_collective + outcome_proportions;
        % p_collective = outcome_proportions_collective;

        % Compute the cumulative distribution function (CDF) and probability density function (PDF)
        %  CDF_collective = p_collective(:, 2);
        %  PDF_collective = diff(CDF_collective) ./ diff(stimulus_values);
        % P_collective(itr, cost_idx, :) = PDF_collective / sum(PDF_collective); % Collective observer distribution
        P_collective_pdf(itr, cost_idx, :) = outcome_proportions_collective_pdf;
        P_collective_cdf(itr, cost_idx, :) = outcome_proportions_collective_cdf;

    end
end

% --- Calculating the estimated  collective JND distribution for the "average observer" ---

load('result_averagel_observer_600_1000_parallel.mat')

num_iterations_average = size(averageObs_thresholdsMLEQuest, 1); % Number of iterations
num_costs_average = size(averageObs_thresholdsMLEQuest, 2); % Number of different costs the approach is evaluated at.
P_average_pdf = nan(num_iterations_average, num_costs_average, length(stimulus_values) );
P_average_cdf = nan(num_iterations_average, num_costs_average, length(stimulus_values) );

for itr = 1:num_iterations_average
    for cost_idx = 1:num_costs_average
        outcome_proportions_individual_all_pdf = zeros(length(stimulus_values), 1);
        outcome_proportions_individual_all_cdf = zeros(length(stimulus_values), 1);

        num_individual_obs = length(averageObs_thresholdsMLEQuest{itr, cost_idx});

        for obs = 1:num_individual_obs
            individual_params = [averageObs_thresholdsMLEQuest{itr, cost_idx}(obs), averageObs_slopesMLEQuest{itr, cost_idx}(obs),0 ];%averageObs_lapsesMLEQuest{itr, cost_idx}(obs)
            %  outcome_proportions = qpPFNormal(stimulus_values, individual_params);
            outcome_proportions1 = normpdf(stimulus_values, individual_params(1),individual_params(2));
            outcome_proportions2 = normcdf(stimulus_values, individual_params(1),individual_params(2));

            outcome_proportions_individual_all_pdf = outcome_proportions_individual_all_pdf + outcome_proportions1/sum(outcome_proportions1);
            outcome_proportions_individual_all_cdf = outcome_proportions_individual_all_cdf + outcome_proportions2;%
        end
        %        p_individual = outcome_proportions_individual_all / num_individual_obs;

        % Compute the cumulative distribution function (CDF) and probability density function (PDF)
        %CDF_individual = p_individual(:, 2);
        %  PDF_individual = diff(CDF_individual) ./ diff(stimulus_values);
        % P_average(itr, cost_idx, :) = PDF_individual / sum(PDF_individual); % Average observer distribution
        P_average_pdf(itr, cost_idx, :) = outcome_proportions_individual_all_pdf/ num_individual_obs;
        P_average_cdf(itr, cost_idx, :) = outcome_proportions_individual_all_cdf/ num_individual_obs;

    end
end

% --- Calculating the estimated JND collective distribution for the "common method" with the relaxed binary search (RBS) ---

%load('result_RBS_300_200.mat')
load('result_RBS_600_1000_updated.mat')

num_iterations_rbs = size(Thresholds_RBS_all, 1); % Number of iterations
num_costs_rbs = size(Thresholds_RBS_all, 2); % Number of different costs the approach is evaluated at.
P_rbs_pdf = nan(num_iterations_rbs, num_costs_rbs, length(stimulus_values) );
P_rbs_cdf = nan(num_iterations_rbs, num_costs_rbs, length(stimulus_values) );

for itr = 1:num_iterations_rbs
    for cost_idx = 1:num_costs_rbs
 
        individual_thresholds_rbs = Thresholds_RBS_all{itr, cost_idx};

        % Fit a normal distribution to the individual JNDs
        mu_rbs = mean(individual_thresholds_rbs);
        sigma_rbs = std(individual_thresholds_rbs);
        if sigma_rbs==0
            sigma_rbs=0.1;
        end

        % Calculate the CDF at points from 0 to 51
        PDF_individual_rbs = normpdf(stimulus_values, mu_rbs, sigma_rbs);
        CDF_individual_rbs = normcdf(stimulus_values, mu_rbs, sigma_rbs);
      
        %PDF_individual_rbs = diff(CDF_individual_rbs) ./ diff(stimulus_values);
        P_rbs_pdf(itr, cost_idx, :) = PDF_individual_rbs/sum(PDF_individual_rbs); % RBS distribution
        P_rbs_cdf(itr, cost_idx, :) = CDF_individual_rbs; % RBS distribution

    end
end

% --- Calculating the estimated JND collective distribution for the "common method" with the standard binary search (SBS) ---

%load('result_SBS_300_200.mat')
% load('result_SBS_600_1000.mat')
% num_iterations_sbs = size(Thresholds_SBS_all, 1); % Number of iterations
% num_costs_sbs = size(Thresholds_SBS_all, 2); % Number of different costs the approach is evaluated at.
% P_sbs_pdf = nan(num_iterations_sbs, num_costs_sbs, length(stimulus_values) );
% P_sbs_cdf = nan(num_iterations_sbs, num_costs_sbs, length(stimulus_values) );
% 
% for itr = 1:num_iterations_sbs
%     for cost_idx = 1:num_costs_sbs
% 
%         individual_thresholds_sbs = Thresholds_SBS_all{itr, cost_idx};
% 
%         % Fit a normal distribution to the individual JNDs
%         mu_sbs = mean(individual_thresholds_sbs);
%         sigma_sbs = std(individual_thresholds_sbs);
% 
%         % Calculate the CDF at points from 0 to 51
%         PDF_individual_sbs = normpdf(stimulus_values, mu_sbs, sigma_sbs);
%         CDF_individual_sbs = normcdf(stimulus_values, mu_sbs, sigma_sbs);
% 
%         P_sbs_pdf(itr, cost_idx, :) = PDF_individual_sbs/sum(PDF_individual_sbs); % SBS distribution
%         P_sbs_cdf(itr, cost_idx, :) = CDF_individual_sbs; % SBS distribution
% 
%     end
% end

% Save the results
save('Prob_Dist_all_1000_runs',  'P_rbs_pdf','P_rbs_cdf', 'P_average_pdf','P_average_cdf', 'P_collective_pdf', 'P_collective_cdf', 'P_ground_truth_pdf', 'P_ground_truth_cdf','stimulus_values');
