function pd1 = createFit(stim_hist)
%CREATEFIT    Create plot of datasets and fits
%   PD1 = CREATEFIT(STIM_HIST)
%   Creates a plot, similar to the plot in the main distribution fitter
%   window, using the data that you provide as input.  You can
%   apply this function to the same data you used with distributionFitter
%   or with different data.  You may want to edit the function to
%   customize the code and this help message.
%
%   Number of datasets:  1
%   Number of fits:  1
%
%   See also FITDIST.

% This function was automatically generated on 06-Jul-2021 19:30:40

% Output fitted probablility distribution: PD1

% Data from dataset "stim_hist data":
%    Y = stim_hist

% Force all inputs to be column vectors
stim_hist = stim_hist(:);

% Prepare figure
clf;
hold on;
LegHandles = []; LegText = {};


% --- Plot data originally in dataset "stim_hist data"
[CdfY,CdfX] = ecdf(stim_hist,'Function','cdf');  % compute empirical function
hLine = stairs(CdfX,CdfY,'Color',[0.333333 0 0.666667],'LineStyle','-', 'LineWidth',1);
xlabel('Stimulus level');
ylabel('Cumulative probability')
LegHandles(end+1) = hLine;
LegText{end+1} = 'Empiricaldata';

% Create grid where function will be computed
XLim = [1 51] %get(gca,'XLim');
XLim = XLim + [-1 1] * 0.01 * diff(XLim);
XGrid = linspace(XLim(1),XLim(2),100);
XAxis.Limits=[0 51]

% --- Create fit "Weibull CDF"

% Fit this distribution to get parameter values
% To use parameter estimates from the original fit:
%     pd1 = ProbDistUnivParam('weibull',[ 37.78493088561, 3.214628934106])
pd1 = fitdist(stim_hist, 'weibull');
YPlot = cdf(pd1,XGrid);
hLine = plot(XGrid,YPlot,'Color',[1 0 0],...
    'LineStyle','-', 'LineWidth',2,...
    'Marker','none', 'MarkerSize',6);
LegHandles(end+1) = hLine;
LegText{end+1} = 'Weibull CDF';

% Adjust figure
box on;
hold off;

% Create legend from accumulated handles and labels
hLegend = legend(LegHandles,LegText,'Orientation', 'vertical', 'FontSize', 9, 'Location', 'northwest');
set(hLegend,'Interpreter','none');

