%qpQuestPlusCSFDemo  Demonstrate/test QUEST+ at work on parametric CSF estimation
%
% Description:
%    This script shows QUEST+ employed to estimate parametric spatial and
%    temporal CSFs.
%
%    Reprises Figure 6 of the paper.

% 07/03/17  dhb  Created.

%% Close out stray figures
%close all;
figure
%% qpRun estimating spatial CSF
%
% This uses the more general qpPFSTCSF, but the temporal frequency
% and its parameter are locked to zero in all places where they come up.
%
% This reprises Figure 6 of the 2017 QUEST+ paper.[width=15cm, height=6cm]

%questData = qpInitialize('stimParamsDomainList',{0:1:51, 0, 0:1:51},'psiParamsDomainList',{0:1:51, -51:1:51, 0.2:0.1:4, 0},'qpPF',@qpPFSTCSF2,'qpOutcomeF',@(x)qpSimulatedObserver(x,@qpPFSTCSF2,simulatedPsiParams),'nOutcomes', 2,'verbose',true);
%load('compression_crf_quest_data.mat')
load('compression_crf_quest_data_with_slope_3_c_0.mat')
%save('compression_crf_quest_data_with_slope_3_c_0.mat', 'questData', '-v7.3')


fprintf('*** qpRun, Estimate parametric compression ratio crf:\n');
rng('default'); rng(3008,'twister');
simulatedPsiParams = [30, 15,0.8, 0];
% questData = qpRun(1000, ...
%     'stimParamsDomainList',{0:1:51, 0, 0:1:51}, ...
%     'psiParamsDomainList',{0:1:51, 0:1:51, 0.2:0.2:4, 0}, ...
%     'qpPF',@qpPFSTCSF, ...
%     'qpOutcomeF',@(x) qpSimulatedObserver(x,@qpPFSTCSF,simulatedPsiParams), ...
%     'nOutcomes', 2, ...
%     'verbose',true);
simulatedObserverFun=@(x) qpSimulatedObserver(x,@qpPFSTCSF2,simulatedPsiParams);
tt=1;
while 1
    % Get stimulus for this trial
    stim = qpQuery(questData);
    stim_list(tt,:)=stim;
    % Simulate outcome
    outcome = simulatedObserverFun(stim);
    outcome_list(tt,:)=outcome;
    questData = qpUpdate(questData,stim,outcome); 
%     if outcome==1 
%             questData = qpUpdate(questData,stim,1); 
%             questData = qpUpdate(questData,stim,1); 
%             uu=uu+1;
%     end
%     
%     if outcome==2 
%             questData = qpUpdate(questData,stim,2); 
%             questData = qpUpdate(questData,stim,2); 
%             uu=uu+1;
%     end
    % Update quest data structure
  %  questData = qpUpdate(questData,stim,outcome); 
 if  questData.entropyAfterTrial(tt)<4
     break;
 end
 Entropy_list(tt,:)=questData.entropyAfterTrial(tt);
 tt=tt+1
end



psiParamsIndex = qpListMaxArg(questData.posterior);
psiParamsQuest = questData.psiParamsDomain(psiParamsIndex,:);
fprintf('Simulated parameters: %0.1f, %0.1f, %0.1f, %0.1f\n', ...
    simulatedPsiParams(1),simulatedPsiParams(2),simulatedPsiParams(3),simulatedPsiParams(4));
fprintf('Max posterior QUEST+ parameters: %0.1f, %0.1f, %0.1f, %0.1f\n', ...
    psiParamsQuest(1),psiParamsQuest(2),psiParamsQuest(3),psiParamsQuest(4));
%psiParamsCheck = [-360000 -500000 12000 0];
%assert(all(psiParamsCheck == round(10000*psiParamsQuest)),'No longer get same QUEST+ estimate for this case');

% Maximum likelihood fit.  Use psiParams from QUEST+ as the starting
% parameter for the search, and impose as parameter bounds the range
% provided to QUEST+.
psiParamsFit = qpFit(questData.trialData,questData.qpPF,psiParamsQuest,questData.nOutcomes,...
    'lowerBounds', [0 -51 0.1 0],'upperBounds',[51 51 4 0]);
fprintf('Maximum likelihood fit parameters: %0.1f, %0.1f, %0.1f, %0.1f\n', ...
    psiParamsFit(1),psiParamsFit(2),psiParamsFit(3),psiParamsFit(4));
%psiParamsCheck = [-359123 -485262 11325 0];
%assert(all(psiParamsCheck == round(10000*psiParamsFit)),'No longer get same ML estimate for this case');
 
% Plot trial locations together with maximum likelihood fit.
%
% Point transparancy visualizes number of trials (more opaque -> more
% trials), while point color visualizes percent correct (more blue -> more
% correct).
figure; clf; hold on
stimCounts = qpCounts(qpData(questData.trialData),questData.nOutcomes);
stim = zeros(length(stimCounts),questData.nStimParams);
for cc = 1:length(stimCounts)
    stim(cc,:) = stimCounts(cc).stim;
    nTrials(cc) = sum(stimCounts(cc).outcomeCounts);
    pCorrect(cc) = stimCounts(cc).outcomeCounts(2)/nTrials(cc);
end
for cc = 1:length(stimCounts)
    h = scatter(stim(cc,3),stim(cc,1),100,'o','MarkerEdgeColor',[1-pCorrect(cc) 0 pCorrect(cc)],'MarkerFaceColor',[1-pCorrect(cc) 0 pCorrect(cc)],...
        'MarkerFaceAlpha',nTrials(cc)/max(nTrials),'MarkerEdgeAlpha',nTrials(cc)/max(nTrials));
end
plotSfs = (0:1:51)';
[~,plotFitThresholds] = qpPFSTCSF2(...
    [plotSfs zeros(size(plotSfs)) zeros(size(plotSfs))], ...
    psiParamsFit);
%plot(plotSfs,plotFitThresholds,'-','Color',[1 0.2 0.0],'LineWidth',3);
plot(plotFitThresholds,plotSfs,'-','Color',[1 0.2 0.0],'LineWidth',3);

ylabel('Compression level');
xlabel('Distortion level');
xlim([-51 51]); ylim([0 51]);
title({'Estimate JND locations', ''});
drawnow;
%save('compression_crf_all_sithe_slope_3.mat', '-v7.3')
