 EXAMPLES
   % ----- Example 1 -----
   % Plot a red patch between 2 dotted confidence interval curves with
   % a midle solid black line.
   x = -2:0.01:2;
   x = x';
   y1 = 0.5*x.^2;
   y2 = 0.25*x.^2;
   y3 = 0.9*x.^2;
   plot_ci(x,[y1 y2 y3], 'PatchColor', 'r', 'PatchAlpha', 0.2, ...
          'MainLineWidth', 2, 'MainLineStyle', '-', 'MainLineColor', 'b', ...
          'LineWidth', 1.5, 'LineStyle','--', 'LineColor', 'k');
   grid on;
   % ----- end of example -----


   % ----- Example 2 -----
   % Plot a yellow line with blue patch between 2 black solid lined confidence intervals
   % and blue 50% transparent patch between them
   y = [0.1489 0.2677 0.0718;...
        0.2056 0.3032 0.1295;...
        0.2733 0.3423 0.2120;...
        0.3506 0.3903 0.3125;...
        0.4347 0.4767 0.3934;...
        0.5218 0.5997 0.4430;...
        0.6079 0.7197 0.4862;...
        0.6889 0.8200 0.5280;...
        0.7618 0.8944 0.5689;...
        0.8241 0.9437 0.6087];
   N = 10;
   x = linspace(40,95,N);
   rgb_fill = [0.3047 0.6992 0.9102];
   rgb_line = [0.9414 0.9414 0.3359];
   figure;
   plot_ci(x,y, 'PatchColor', rgb_fill, 'PatchAlpha', 0.5, ...
          'MainLineWidth', 3, 'MainLineColor', rgb_line, ...
          'LineWidth', 1, 'LineStyle','-', 'LineColor', 'k');
   grid on;
   % ----- end of example -----
 

   % ----- Example 3 -----
   % This example is similar to previous, however, it shows that the
   % graph can be built separately by holding an axes
   y = [0.1489 0.2677 0.0718;...
        0.2056 0.3032 0.1295;...
        0.2733 0.3423 0.2120;...
        0.3506 0.3903 0.3125;...
        0.4347 0.4767 0.3934;...
        0.5218 0.5997 0.4430;...
        0.6079 0.7197 0.4862;...
        0.6889 0.8200 0.5280;...
        0.7618 0.8944 0.5689;...
        0.8241 0.9437 0.6087];
   N = 10;
   x = linspace(40,95,N);
   rgb_fill = [0.3047 0.6992 0.9102];
   rgb_line = [0.9414 0.9414 0.3359];
   figure;
   plot_ci(x,y(:,1), 'MainLineWidth', 3);
   hold on;
   plot_ci(x,y(:,2:3), 'LineStyle',':', 'LineColor', 'k', ...
          'PatchColor', rgb_fill, 'PatchAlpha', 0);
   grid on;
   hold off;
   % ----- end of example -----

   
   % ----- Example 4 -----
   % This example present the application of parameter AxesHandle
   x = -2:0.01:2;
   x = x';
   y1 = 0.5*x.^2;
   y2 = 0.25*x.^2;
   y3 = 0.9*x.^2;
   f = figure; ax = axes('Parent',f);
   plot_ci(x,[y2 y3], 'PatchColor', 'r', 'PatchAlpha', 0.2, ...
        'LineWidth', 1.5, 'LineStyle','--', 'LineColor', 'k', ...
		'AxesHandle',ax);
   hold(ax,'all');
   plot_ci(x,y1, 'MainLineWidth', 2, 'MainLineStyle', '-', 'MainLineColor', 'b', ...
        'AxesHandle',ax);
   grid on;
   hold(ax,'off');
   % ----- end of example -----


   % ----- Example 5 -----
   % Plot 2 graphs in one figure:
   %    a red line with red patch of 10% transparency and
   %    a green line with green patch of 10% transparency
   % This example shows that 2 separate graphs can be drawn
   % by by holding an axes
   y1 = [0.1489 0.2677 0.0718;...
        0.2056 0.3032 0.1295;...
        0.2733 0.3423 0.2120;...
        0.3506 0.3903 0.3125;...
        0.4347 0.4767 0.3934;...
        0.5218 0.5997 0.4430;...
        0.6079 0.7197 0.4862;...
        0.6889 0.8200 0.5280;...
        0.7618 0.8944 0.5689;...
        0.8241 0.9437 0.6087];
   N = 10;
   x = linspace(40,95,N);
   figure;
   plot_ci(x,y1, 'PatchColor', 'g', 'PatchAlpha', 0.1, ...
          'MainLineWidth', 2, 'MainLineColor', 'g', ...
          'LineWidth', 1, 'LineStyle','-', 'LineColor', 'k');
   hold on
   grid on;
   
   y2 = [0.0254 0.0640 0.0085; ...
        0.0414 0.0785 0.0200; ...
        0.0649 0.0964 0.0420; ...
        0.0975 0.1215 0.0771; ...
        0.1407 0.1705 0.1147; ...
        0.1955 0.2572 0.1437; ...
        0.2615 0.3717 0.1710; ...
        0.3374 0.5016 0.1995; ...
        0.4205 0.6322 0.2300; ...
        0.5074 0.7494 0.2626];
   plot_ci(x,y2, 'PatchColor', 'r', 'PatchAlpha', 0.1, ...
          'MainLineWidth', 2, 'MainLineColor', 'r', ...
          'LineWidth', 1, 'LineStyle','--', 'LineColor', 'k');
   % ----- end of example -----