clear, clc

addpath(genpath("./plot_ci"));
addpath(genpath("./mQUESTPlus"));
addpath(genpath("./matlab2tikz_code"));
% Set the parameters
% Set the parameters for thresholds
mean_threshold = 26;          % Mean of the thresholds distribution
variance_threshold = 36;      % Variance of the thresholds distribution
num_values = 10000;           % Number of random values to generate
lower_limit_threshold = 1;    % Lower limit for the thresholds
upper_limit_threshold = 51;   % Upper limit for the thresholds

% Set the parameters for slopes
mean_slope = 5.5;             % Mean of the slopes distribution
variance_slope = 1.2;         % Variance of the slopes distribution
lower_limit_slope = 1;        % Lower limit for the slopes
upper_limit_slope = 10;       % Upper limit for the slopes

% Set the parameters for lapses
mean_lapse = 0.02;            % Mean of the lapses distribution
variance_lapse = 0.00002;     % Variance of the lapses distribution
lower_limit_lapse = 0;        % Lower limit for the lapses
upper_limit_lapse = 0.04;     % Upper limit for the lapses

% Set the seed for reproducibility
rng(295636);% rng(28177);

% Generate normally distributed random values for thresholds
thresholds = normrnd(mean_threshold, sqrt(variance_threshold), [1, num_values]);
thresholds = max(lower_limit_threshold, min(upper_limit_threshold, thresholds));

% Generate normally distributed random values for slopes
slopes = normrnd(mean_slope, sqrt(variance_slope), [1, num_values]);
slopes = max(lower_limit_slope, min(upper_limit_slope, slopes));

% Generate normally distributed random values for lapses
lapses = normrnd(mean_lapse, sqrt(variance_lapse), [1, num_values]);
lapses = max(lower_limit_lapse, min(upper_limit_lapse, lapses));

% Ensure the desired number of values for thresholds
while numel(thresholds) < num_values
    additional_values = normrnd(mean_threshold, sqrt(variance_threshold), [1, num_values - numel(thresholds)]);
    additional_values = max(lower_limit_threshold, min(upper_limit_threshold, additional_values));
    thresholds = [thresholds, additional_values];
end
thresholds = thresholds(1:num_values);

% Ensure the desired number of values for slopes
while numel(slopes) < num_values
    additional_values = normrnd(mean_slope, sqrt(variance_slope), [1, num_values - numel(slopes)]);
    additional_values = max(lower_limit_slope, min(upper_limit_slope, additional_values));
    slopes = [slopes, additional_values];
end
slopes = slopes(1:num_values);

% Ensure the desired number of values for lapses
while numel(lapses) < num_values
    additional_values = normrnd(mean_lapse, sqrt(variance_lapse), [1, num_values - numel(lapses)]);
    additional_values = max(lower_limit_lapse, min(upper_limit_lapse, additional_values));
    lapses = [lapses, additional_values];
end
lapses = lapses(1:num_values);

% Simulation for Standard Binary search


% Set the search space
lower_limit = 1;
upper_limit = 51;
search_space = 1:51;

% Function to perform binary search for the threshold estimation
binarySearchThreshold = @(search_fun) relaxedBinarySearch(search_space, search_fun);

for itr =1:1000
    PCs_index = 0;

    for PCs_range = 30:30:600
        PCs_index = PCs_index + 1;
        PCS_num = 0;
        Thresholds_RBS = [];
        num_comparisons_RBS = [];
        while PCS_num <= PCs_range

            observer_number = randi([1 10000],1);
            simulatedPsiParams = [thresholds(observer_number), slopes(observer_number), lapses(observer_number)];

            % Define the simulated observer function
            simulatedObserverFun = @(x) qpSimulatedObserver(x, @qpPFNormal, simulatedPsiParams);


            % Perform binary search for the threshold estimation
            [estimatedThreshold, num_comparisons] = binarySearchThreshold(simulatedObserverFun);

            PCS_num = PCS_num + num_comparisons;
            if PCS_num <= PCs_range
                Thresholds_RBS = [Thresholds_RBS estimatedThreshold];
                num_comparisons_RBS = [num_comparisons_RBS num_comparisons];
            end
        end
        Thresholds_RBS_all{itr,PCs_index} = Thresholds_RBS;
        num_comparisons_RBS_all{itr,PCs_index} = num_comparisons_RBS;

    end
    disp(itr)
end
save result_RBS_600_1000_updated